@@ -43,8 +43,8 @@
 #' LASfile <- system.file("extdata", "Megaplot.laz", package="lidR")
 #' lidar = readLAS(LASfile)
 #'
-#' voxels = voxel_metrics(lidar, list(Imean = mean(Intensity)))
-#' plot(voxels, color = "Imean", colorPalette = heat.colors(50), trim=0.99)
+#' voxels = voxel_metrics(lidar, list(Imean = mean(Intensity)), res = 5)
+#' plot(voxels, color = "Imean", colorPalette = heat.colors(50), trim=60)
 #' @export
 #' @method plot lasmetrics3d
 plot.lasmetrics3d = function(x, y, color = "Z", colorPalette = height.colors(50), bg = "black", trim = Inf, ...)
@@ -106,7 +106,7 @@ plot.lasmetrics3d = function(x, y, color = "Z", colorPalette = height.colors(50)
 #' @name plot_3d
 #' @examples
 #' LASfile <- system.file("extdata", "Topography.laz", package="lidR")
-#' las = readLAS(LASfile)
+#' las = readLAS(LASfile, filter = "-keep_xy 273450 273600 5274450 5274600")
 #'
 #' dtm = grid_terrain(las, algorithm = tin())
 #' ttops <- find_trees(las, lmf(ws = 5))
@@ -138,6 +138,13 @@ plot_dtm3d = function(dtm, bg = "black", clear_artifacts = TRUE, ...)
   }
 
   add_dtm3d(shift, dtm, ...)
+
+  .pan3d(2)
+
+  if (clear_artifacts)
+    return(invisible(shift))
+  else
+    return(invisible(c(0,0)))
 }
 
 #' @rdname plot_3d
