@@ -112,10 +112,12 @@ LIDRSNG <- "SnagsSegmentation"
 LIDRITS <- "IndividualTreeSegmentation"
 LIDRNIT <- "normalize_intensity"
 LIDRTRK <- "SensorTracking"
+LIDROUT <- "NoiseSegmentation"
 
 LIDRCONTEXTDSM <- "grid_canopy"
 LIDRCONTEXTSPI <- c("normalize_height", "grid_terrain", "p2r", "spatial_interpolation")
 LIDRCONTEXTGND <- "classify_ground"
+LIDRCONTEXTOUT <- "classify_noise"
 LIDRCONTEXTITD <- "find_trees"
 LIDRCONTEXTDEC <- "decimate_points"
 LIDRCONTEXTSHP <- "segment_shapes"
@@ -129,7 +131,7 @@ LIDRALGORITHMGENERIC = c(LIDRALGORITHM, "ANY", "function")
 LIDRALGORITHMOPENMP <- "OpenMP"
 LIDRALGORITHMPOINTCLOUDBASED <- "PointCloudBased"
 LIDRALGORITHMRASTERBASED <- "RasterBased"
-LIDRALGORITHMDEC <- LIDRALGORITHMDSM <- LIDRALGORITHMGND <- LIDRALGORITHMITD <- LIDRALGORITHMITS <- LIDRALGORITHMNIT <- LIDRALGORITHMSNG <- LIDRALGORITHMTRK <- LIDRALGORITHMSHP <- LIDRALGORITHMSPI <- LIDRALGORITHMGENERIC
+LIDRALGORITHMDEC <- LIDRALGORITHMDSM <- LIDRALGORITHMGND <- LIDRALGORITHMITD <- LIDRALGORITHMITS <- LIDRALGORITHMNIT <- LIDRALGORITHMSNG <- LIDRALGORITHMTRK <- LIDRALGORITHMSHP <- LIDRALGORITHMSPI <- LIDRALGORITHMOUT <- LIDRALGORITHMGENERIC
 LIDRALGORITHMDEC[2] <- LIDRDEC
 LIDRALGORITHMDSM[2] <- LIDRDSM
 LIDRALGORITHMGND[2] <- LIDRGND
@@ -140,3 +142,4 @@ LIDRALGORITHMSNG[2] <- LIDRSNG
 LIDRALGORITHMTRK[2] <- LIDRTRK
 LIDRALGORITHMSHP[2] <- LIDRSHP
 LIDRALGORITHMSPI[2] <- LIDRSPI
+LIDRALGORITHMOUT[2] <- LIDROUT
