@@ -74,49 +74,40 @@
 #' @param th numeric. Threshold for metrics pzabovex. Can be a vector to compute with several thresholds.
 #' @examples
 #' LASfile <- system.file("extdata", "Megaplot.laz", package="lidR")
-#' las = readLAS(LASfile, select = "*")
+#' las <- readLAS(LASfile, select = "*", filter = "-keep_random_fraction 0.5")
 #'
 #' # All the predefined metrics
-#' m1 = grid_metrics(las, ~stdmetrics(X,Y,Z,Intensity,ReturnNumber,Classification,dz=1))
+#' m1 <- grid_metrics(las, ~stdmetrics(X,Y,Z,Intensity,ReturnNumber,Classification,dz=1), res = 40)
 #'
 #' # Convenient shortcut
-#' m2 = grid_metrics(las, .stdmetrics)
+#' m2 <- grid_metrics(las, .stdmetrics, res = 40)
 #'
 #' # Basic metrics from intensities
-#' m3 = grid_metrics(las, ~stdmetrics_i(Intensity))
+#' m3 <- grid_metrics(las, ~stdmetrics_i(Intensity), res = 40)
 #'
 #' # All the metrics from intensities
-#' m4 = grid_metrics(las, ~stdmetrics_i(Intensity, Z, Classification, ReturnNumber))
+#' m4 <- grid_metrics(las, ~stdmetrics_i(Intensity, Z, Classification, ReturnNumber), res = 40)
 #'
 #' # Convenient shortcut for the previous example
-#' m5 = grid_metrics(las, .stdmetrics_i)
-#'
-#' # Compute the metrics only on first return
-#' first = filter_first(las)
-#' m6 = grid_metrics(first, .stdmetrics_z)
-#'
-#' # Compute the metrics with a threshold at 2 meters
-#' over2 = filter_poi(las, Z > 2)
-#' m7 = grid_metrics(over2, .stdmetrics_z)
+#' m5 <- grid_metrics(las, .stdmetrics_i, res = 40)
 #'
 #' # Works also with cloud_metrics and hexbin_metrics
-#' m8 = cloud_metrics(las, .stdmetrics)
-#' m9 = hexbin_metrics(las, .stdmetrics)
+#' m6 <- cloud_metrics(las, .stdmetrics)
+#' m7 <- hexbin_metrics(las, .stdmetrics)
 #'
 #' # Combine some predefined function with your own new metrics
 #' # Here convenient shortcuts are no longer usable.
 #' myMetrics = function(z, i, rn)
 #' {
-#'   first  = rn == 1L
-#'   zfirst = z[first]
-#'   nfirst = length(zfirst)
-#'   above2 = sum(z > 2)
+#'   first  <- rn == 1L
+#'   zfirst <- z[first]
+#'   nfirst <- length(zfirst)
+#'   above2 <- sum(z > 2)
 #'
-#'   x = above2/nfirst*100
-
+#'   x <- above2/nfirst*100
 #'
 #'   # User's metrics
-#'   metrics = list(
+#'   metrics <- list(
 #'      above2aboven1st = x,       # Num of returns above 2 divided by num of 1st returns
 #'      zimean  = mean(z*i),       # Mean products of z by intensity
 #'      zsqmean = sqrt(mean(z^2))  # Quadratic mean of z
@@ -126,12 +117,11 @@
 #'   return( c(metrics, stdmetrics_z(z)) )
 #' }
 #'
-#' m10 = grid_metrics(las, ~myMetrics(Z, Intensity, ReturnNumber))
+#' m10 <- grid_metrics(las, ~myMetrics(Z, Intensity, ReturnNumber), res = 40)
 #'
 #' # Users can write their own convenient shorcuts like this:
 #' .myMetrics = ~myMetrics(Z, Intensity, ReturnNumber)
-#'
-#' m11 = grid_metrics(las, .myMetrics)
+#' m11 <- grid_metrics(las, .myMetrics, res = 40)
 #' @seealso
 #' \link{cloud_metrics}
 #' \link{grid_metrics}
@@ -143,13 +133,13 @@
 #' @export
 stdmetrics = function(x, y, z, i, rn, class, dz = 1, th = 2)
 {
-  C  = stdmetrics_ctrl(x, y, z)
-  Z  = stdmetrics_z(z, dz, th)
-  I  = stdmetrics_i(i, z, class, rn)
-  RN = stdmetrics_rn(rn, class)
+  C  <- stdmetrics_ctrl(x, y, z)
+  Z  <- stdmetrics_z(z, dz, th)
+  I  <- stdmetrics_i(i, z, class, rn)
+  RN <- stdmetrics_rn(rn, class)
   #PU = stdmetrics_pulse(pulseID, rn)
 
-  metrics = c(Z, I, RN, C)
+  metrics <- c(Z, I, RN, C)
   return(metrics)
 }
 
@@ -157,35 +147,35 @@ stdmetrics = function(x, y, z, i, rn, class, dz = 1, th = 2)
 #' @export
 stdmetrics_z = function(z, dz = 1, th = 2)
 {
-  n = length(z)
-  zmax  = max(z)
-  zmean = mean(z)
+  n <- length(z)
+  zmax  <- max(z)
+  zmean <- mean(z)
 
-  probs = seq(0.05, 0.95, 0.05)
-  zq 	  = as.list(stats::quantile(z, probs))
-  names(zq) = paste0("zq", probs*100)
+  probs <- seq(0.05, 0.95, 0.05)
+  zq 	  <- as.list(stats::quantile(z, probs))
+  names(zq) <- paste0("zq", probs*100)
 
-  pzabovex = lapply(th, function(x) { fast_countover(z, x) / n * 100 })
-  names(pzabovex) = paste0("pzabove", th)
+  pzabovex <- lapply(th, function(x) { fast_countover(z, x) / n * 100 })
+  names(pzabovex) <- paste0("pzabove", th)
 
-  pzabovemean = fast_countover(z, zmean) / n * 100
+  pzabovemean <- fast_countover(z, zmean) / n * 100
 
   if (zmax <= 0)
   {
-    d = rep(0, 9)
+    d <- rep(0, 9)
   }
   else
   {
-    breaks = seq(0, zmax, zmax/10)
-    d = findInterval(z, breaks)
-    d = fast_table(d, 10)
-    d = d / sum(d)*100
-    d = cumsum(d)[1:9]
-    d = as.list(d)
+    breaks <- seq(0, zmax, zmax/10)
+    d <- findInterval(z, breaks)
+    d <- fast_table(d, 10)
+    d <- d / sum(d)*100
+    d <- cumsum(d)[1:9]
+    d <- as.list(d)
   }
-  names(d) = paste0("zpcum", 1:9)
+  names(d) <- paste0("zpcum", 1:9)
 
-  metrics = list(
+  metrics <- list(
     zmax  = zmax,
     zmean = zmean,
     zsd   = stats::sd(z),
@@ -195,7 +185,7 @@ stdmetrics_z = function(z, dz = 1, th = 2)
     pzabovezmean = pzabovemean
   )
 
-  metrics = c(metrics, pzabovex, zq, d)
+  metrics <- c(metrics, pzabovex, zq, d)
 
   return(metrics)
 }
@@ -208,15 +198,15 @@ stdmetrics_i = function(i, z = NULL, class = NULL, rn = NULL)
   icumzq10 <- icumzq30 <- icumzq50 <- icumzq70 <- icumzq90 <- NULL
   itot1st <- itot2sd <- itot3rd <- itot4th  <- itot5th <- NULL
 
-  n = length(i)
-  itot = sum(i)
-  imean = mean(i)
+  n <- length(i)
+  itot <- sum(i)
+  imean <- mean(i)
 
-  probs = seq(0.05, 0.95, 0.05)
-  iq 	  = as.list(stats::quantile(i, probs))
-  names(iq) = paste("iq", probs*100, sep = "")
+  probs <- seq(0.05, 0.95, 0.05)
+  iq 	  <- as.list(stats::quantile(i, probs))
+  names(iq) <- paste("iq", probs*100, sep = "")
 
-  metrics = list(
+  metrics <- list(
     itot = itot,
     imax  = max(i),
     imean = imean,
@@ -227,14 +217,14 @@ stdmetrics_i = function(i, z = NULL, class = NULL, rn = NULL)
 
   if (!is.null(class))
   {
-    metrics = c(metrics, list(ipground = sum(i[class == 2])/itot*100))
+    metrics <- c(metrics, list(ipground = sum(i[class == 2])/itot*100))
   }
 
   if (!is.null(z))
   {
-    zq = stats::quantile(z, probs = seq(0.1, 0.9, 0.2))
+    zq <- stats::quantile(z, probs = seq(0.1, 0.9, 0.2))
 
-    ipcum = list(
+    ipcum <- list(
       ipcumzq10 = sum(i[z <= zq[1]])/itot*100,
       ipcumzq30 = sum(i[z <= zq[2]])/itot*100,
       ipcumzq50 = sum(i[z <= zq[3]])/itot*100,
@@ -242,7 +232,7 @@ stdmetrics_i = function(i, z = NULL, class = NULL, rn = NULL)
       ipcumzq90 = sum(i[z <= zq[5]])/itot*100
     )
 
-    metrics = c(metrics, ipcum)
+    metrics <- c(metrics, ipcum)
   }
 
   metrics
@@ -254,13 +244,13 @@ stdmetrics_rn = function(rn, class = NULL)
 {
   nground <- NULL
 
-  n = length(rn)
+  n <- length(rn)
 
-  prn = table(factor(rn, levels = c(1:5)))/n*100
-  prn = as.list(prn)
-  names(prn) = paste0("p", names(prn), "th")
+  prn <- table(factor(rn, levels = c(1:5)))/n*100
+  prn <- as.list(prn)
+  names(prn) <- paste0("p", names(prn), "th")
 
-  metrics = prn
+  metrics <- prn
 
   if (!is.null(class))
     metrics = c(metrics, list(pground = sum(class == 2)/n*100))
@@ -274,17 +264,17 @@ stdmetrics_pulse = function(pulseID, rn)
 {
   . <- nr <- NULL
 
-  n = length(rn)
+  n <- length(rn)
 
-  dt = data.table::data.table(pulseID, rn)
+  dt <- data.table::data.table(pulseID, rn)
 
-  np_with_x_return = dt[, .(nr = max(rn)), by = pulseID][, .N, by = nr]
+  np_with_x_return <- dt[, .(nr = max(rn)), by = pulseID][, .N, by = nr]
   data.table::setorder(np_with_x_return, nr)
 
-  np = numeric(9)
-  names(np) = paste0("ppulse", 1:9, "return")
-  np[np_with_x_return$nr] = np_with_x_return$N/n*100
-  np = as.list(np)
+  np <- numeric(9)
+  names(np) <- paste0("ppulse", 1:9, "return")
+  np[np_with_x_return$nr] <- np_with_x_return$N/n*100
+  np <- as.list(np)
 
   return(np)
 }
@@ -293,13 +283,13 @@ stdmetrics_pulse = function(pulseID, rn)
 #' @export
 stdmetrics_ctrl = function(x, y, z)
 {
-  xmax = max(x)
-  ymax = max(y)
-  xmin = min(x)
-  ymin = min(y)
-  n    = length(z)
-  area = (xmax - xmin)*(ymax - ymin)
-  metrics = list(n = n, area = area)
+  xmax <- max(x)
+  ymax <- max(y)
+  xmin <- min(x)
+  ymin <- min(y)
+  n    <- length(z)
+  area <- (xmax - xmin)*(ymax - ymin)
+  metrics <- list(n = n, area = area)
 
   return(metrics)
 }
@@ -308,7 +298,7 @@ stdmetrics_ctrl = function(x, y, z)
 #' @export
 stdtreemetrics = function(x, y, z)
 {
-  metrics = list(
+  metrics <- list(
     Z = max(z),
     npoints = length(x),
     convhull_area = round(area_convex_hull(x,y),3)
@@ -328,7 +318,7 @@ stdshapemetrics = function(x,y,z)
   eigen_m <- eigen[[1]]
   eigen_m <- as.numeric(eigen_m)
 
-  shapemetrics = list(
+  shapemetrics <- list(
     eigen_largest  = eigen_m[1],
     eigen_medium   = eigen_m[2],
     eigen_smallest = eigen_m[3],
@@ -354,11 +344,11 @@ stdtreehullconvex = function(x,y,z,grp, ...)
   if (length(x) < 4)
     return(NULL)
 
-  i = grDevices::chull(x,y)
-  i = c(i, i[1])
-  P = cbind(x[i], y[i])
-  poly = sp::Polygon(P)
-  poly = sp::Polygons(list(poly), ID = grp)
+  i <- grDevices::chull(x,y)
+  i <- c(i, i[1])
+  P <- cbind(x[i], y[i])
+  poly <- sp::Polygon(P)
+  poly <- sp::Polygons(list(poly), ID = grp)
 
   j <- which.max(z)
 
@@ -370,9 +360,9 @@ stdtreehullconcave = function(x,y,z,grp, concavity, length_threshold)
   if (length(x) < 4)
     return(NULL)
 
-  P = concaveman::concaveman(cbind(x,y), concavity, length_threshold)
-  poly = sp::Polygon(P)
-  poly = sp::Polygons(list(poly), ID = grp)
+  P <- concaveman::concaveman(cbind(x,y), concavity, length_threshold)
+  poly <- sp::Polygon(P)
+  poly <- sp::Polygons(list(poly), ID = grp)
 
   j <- which.max(z)
 
@@ -384,16 +374,16 @@ stdtreehullbbox = function(x,y,z, grp, ...)
   if (length(x) < 4)
     return(NULL)
 
-  xmin = min(x)
-  ymin = min(y)
-  xmax = max(x)
-  ymax = max(y)
+  xmin <- min(x)
+  ymin <- min(y)
+  xmax <- max(x)
+  ymax <- max(y)
 
-  x = c(xmin, xmax, xmax, xmin, xmin)
-  y = c(ymin, ymin, ymax, ymax, ymin)
-  P = cbind(x, y)
-  poly = sp::Polygon(P)
-  poly = sp::Polygons(list(poly), ID = grp)
+  x <- c(xmin, xmax, xmax, xmin, xmin)
+  y <- c(ymin, ymin, ymax, ymax, ymin)
+  P <- cbind(x, y)
+  poly <- sp::Polygon(P)
+  poly <- sp::Polygons(list(poly), ID = grp)
 
   j <- which.max(z)
 
@@ -437,10 +427,10 @@ stdtreehullbbox = function(x,y,z, grp, ...)
 #' Rumple index of roughness
 #'
 #' Computes the roughness of a surface as the ratio between its area and its
-#' projected area on the ground. If the input is a gridded object (lasmetric or raster) the
-#' function computes the surfaces using Jenness's algorithm (see references). If the input
-#' is a point cloud the function uses a Delaunay triangulation of the points and computes
-#' the area of each triangle.
+#' projected area on the ground. If the input is a gridded object (raster) the
+#' function computes the surfaces using Jenness's algorithm (see references). If
+#' the input is a point cloud the function uses a Delaunay triangulation of the
+#' points and computes the area of each triangle.
 #'
 #' @param x A 'RasterLayer' or a vector of x point coordinates.
 #' @param y numeric. If \code{x} is a vector of coordinates: the associated y coordinates.
@@ -451,19 +441,19 @@ stdtreehullbbox = function(x,y,z, grp, ...)
 #'
 #' @export
 #' @examples
-#' x = runif(20, 0, 100)
-#' y = runif(20, 0, 100)
+#' x <- runif(20, 0, 100)
+#' y <- runif(20, 0, 100)
 #'
 #' # Perfectly flat surface, rumple_index = 1
-#' z = rep(10, 20)
+#' z <- rep(10, 20)
 #' rumple_index(x, y, z)
 #'
 #' # Rough surface, rumple_index > 1
-#' z = runif(20, 0, 10)
+#' z <- runif(20, 0, 10)
 #' rumple_index(x, y, z)
 #'
 #' # Rougher surface, rumple_index increases
-#' z = runif(20, 0, 50)
+#' z <- runif(20, 0, 50)
 #' rumple_index(x, y, z)
 #'
 #' # Measure of roughness is scale-dependent
@@ -472,11 +462,12 @@ stdtreehullbbox = function(x,y,z, grp, ...)
 #'
 #' # Use with a canopy height model
 #' LASfile <- system.file("extdata", "Megaplot.laz", package="lidR")
-#' las = readLAS(LASfile)
-#' chm = grid_canopy(las, 2, p2r())
+#' las <- readLAS(LASfile)
+#' chm <- grid_canopy(las, 2, p2r())
 #' rumple_index(chm)
 #' @references
-#' Jenness, J. S. (2004). Calculating landscape surface area from digital elevation models. Wildlife Society Bulletin, 32(3), 829–839.
+#' Jenness, J. S. (2004). Calculating landscape surface area from digital elevation
+#' models. Wildlife Society Bulletin, 32(3), 829–839.
 rumple_index = function(x, y = NULL, z = NULL, ...)
 {
   UseMethod("rumple_index", x)
@@ -485,15 +476,15 @@ rumple_index = function(x, y = NULL, z = NULL, ...)
 #' @export
 rumple_index.RasterLayer <- function(x, y = NULL, z = NULL, ...)
 {
-  res = raster::res(x)
-  x = raster::as.matrix(x)
+  res <- raster::res(x)
+  x <- raster::as.matrix(x)
   return(rumple_index.matrix(x, res[1], res[2]))
 }
 
 rumple_index.matrix <- function(x, y = NULL, z = NULL, ...)
 {
-  area  = sp::surfaceArea(x, y, z)
-  parea = sum(!is.na(x))*y*z
+  area  <- sp::surfaceArea(x, y, z)
+  parea <- sum(!is.na(x))*y*z
   return(area/parea)
 }
 
@@ -509,21 +500,21 @@ rumple_index.numeric <- function(x, y = NULL, z = NULL, ...)
   if (length(x) <= 3)
     return(NA_real_)
 
-  rumple = tryCatch(
-    {
-      X = cbind(x,y,z)
-      dn = suppressMessages(geometry::delaunayn(X[,1:2], options = "QbB"))
-      N = C_tinfo(dn, X)
-      area  = sum(N[,5])
-      parea = sum(N[,6])
-      return(area/parea)
-    },
-    error = function(e)
-    {
-      message(paste0(e, "\n'rumple_index' returned NA."))
-      if (getOption("lidR.debug")) dput(X[,1:2])
-      return(NA_real_)
-    })
+  rumple <- tryCatch(
+  {
+    X <- cbind(x,y,z)
+    dn <- suppressMessages(geometry::delaunayn(X[,1:2], options = "QbB"))
+    N <- C_tinfo(dn, X)
+    area  <- sum(N[,5])
+    parea <- sum(N[,6])
+    return(area/parea)
+  },
+  error = function(e)
+  {
+    message(paste0(e, "\n'rumple_index' returned NA."))
+    if (getOption("lidR.debug")) dput(X[,1:2])
+    return(NA_real_)
+  })
 
   return(rumple)
 }
@@ -542,8 +533,8 @@ rumple_index.numeric <- function(x, y = NULL, z = NULL, ...)
 #' @param z0 numeric. The bottom limit of the profile
 #' @return A data.frame containing the bin elevations (z) and the gap fraction for each bin (gf)
 #' @examples
-#' z = c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
-#' z = z[z<45 & z>0]
+#' z <- c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
+#' z <- z[z<45 & z>0]
 #'
 #' hist(z, n=50)
 #'
@@ -555,19 +546,19 @@ rumple_index.numeric <- function(x, y = NULL, z = NULL, ...)
 #' @export gap_fraction_profile
 gap_fraction_profile = function(z, dz = 1, z0 = 2)
 {
-  bk = seq(floor((min(z) - z0)/dz)*dz + z0, ceiling((max(z) - z0)/dz)*dz + z0, dz)
+  bk <- seq(floor((min(z) - z0)/dz)*dz + z0, ceiling((max(z) - z0)/dz)*dz + z0, dz)
 
   if (length(bk) <= 1)
     return(data.frame(z = numeric(0), gf = numeric(0)))
 
-  histogram = graphics::hist(z, breaks = bk, plot = F)
-  h = histogram$mids
-  p = histogram$counts/sum(histogram$counts)
+  histogram <- graphics::hist(z, breaks = bk, plot = F)
+  h <- histogram$mids
+  p <- histogram$counts/sum(histogram$counts)
 
-  p = c(p, 0)
+  p <- c(p, 0)
 
-  cs = cumsum(p)
-  i = data.table::shift(cs)/cs
+  cs <- cumsum(p)
+  i <- data.table::shift(cs)/cs
   i[is.na(i)] = 0
 
   i[is.nan(i)] = NA
@@ -594,10 +585,10 @@ gap_fraction_profile = function(z, dz = 1, z0 = 2)
 #' @param z0 numeric. The bottom limit of the profile
 #' @return A data.frame containing the bin elevations (z) and leaf area density for each bin (lad)
 #' @examples
-#' z = c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
-#' z = z[z<45 & z>0]
+#' z <- c(rnorm(1e4, 25, 6), rgamma(1e3, 1, 8)*6, rgamma(5e2, 5,5)*10)
+#' z <- z[z<45 & z>0]
 #'
-#' lad = LAD(z)
+#' lad <- LAD(z)
 #'
 #' plot(lad, type="l", xlab="Elevation", ylab="Leaf area density")
 #' @references Bouvier, M., Durrieu, S., Fournier, R. a, & Renaud, J. (2015).  Generalizing predictive models of forest inventory attributes using an area-based approach with airborne las data. Remote Sensing of Environment, 156, 322-334. http://doi.org/10.1016/j.rse.2014.10.004
@@ -605,7 +596,7 @@ gap_fraction_profile = function(z, dz = 1, z0 = 2)
 #' @export LAD
 LAD = function(z, dz = 1, k = 0.5, z0 = 2) # (Bouvier et al. 2015)
 {
-  ld = gap_fraction_profile(z, dz, z0)
+  ld <- gap_fraction_profile(z, dz, z0)
 
   if (nrow(ld) <= 2)
     return(data.frame(z = numeric(0), lad = numeric(0)))
@@ -613,12 +604,12 @@ LAD = function(z, dz = 1, k = 0.5, z0 = 2) # (Bouvier et al. 2015)
   if (anyNA(ld))
     return(data.frame(z = numeric(0), lad = numeric(0)))
 
-  lad = ld$gf
-  lad = -log(lad)/(k*dz)
+  lad <- ld$gf
+  lad <- -log(lad)/(k*dz)
 
   lad[is.infinite(lad)] = NA
 
-  lad = lad
+  lad <- lad
 
   return(data.frame(z = ld$z, lad = lad))
 }
@@ -639,17 +630,17 @@ LAD = function(z, dz = 1, k = 0.5, z0 = 2) # (Bouvier et al. 2015)
 #' @seealso
 #' \link[=VCI]{VCI}
 #' @examples
-#' z = runif(10000, 0, 10)
+#' z <- runif(10000, 0, 10)
 #'
 #' # expected to be close to 1. The highest diversity is given for a uniform distribution
 #' entropy(z, by = 1)
 #'
-#'  z = runif(10000, 9, 10)
+#'  z <- runif(10000, 9, 10)
 #'
 #' # Must be 0. The lowest diversity is given for a unique possibility
 #' entropy(z, by = 1)
 #'
-#' z = abs(rnorm(10000, 10, 1))
+#' z <- abs(rnorm(10000, 10, 1))
 #'
 #' # expected to be between 0 and 1.
 #' entropy(z, by = 1)
@@ -672,19 +663,19 @@ entropy = function(z, by = 1, zmax = NULL)
     return(NA_real_)
 
   # Define the number of x meters bins from 0 to zmax (rounded to the next integer)
-  bk = seq(0, ceiling(zmax/by)*by, by)
+  bk <- seq(0, ceiling(zmax/by)*by, by)
 
   # Compute the p for each bin
-  hist = findInterval(z, bk)
-  hist = fast_table(hist, length(bk) - 1)
-  hist = hist/sum(hist)
+  hist <- findInterval(z, bk)
+  hist <- fast_table(hist, length(bk) - 1)
+  hist <- hist/sum(hist)
 
   # Remove bins where there are no points because of log(0)
-  p    = hist[hist > 0]
-  pref = rep(1/length(hist), length(hist))
+  p    <- hist[hist > 0]
+  pref <- rep(1/length(hist), length(hist))
 
   # normalized entropy
-  S = -sum(p*log(p)) / -sum(pref*log(pref))
+  S <- -sum(p*log(p)) / -sum(pref*log(pref))
 
   return(S)
 }
@@ -699,11 +690,11 @@ entropy = function(z, by = 1, zmax = NULL)
 #' @seealso
 #' \link[=entropy]{entropy}
 #' @examples
-#' z = runif(10000, 0, 10)
+#' z <- runif(10000, 0, 10)
 #'
 #' VCI(z, by = 1, zmax = 20)
 #'
-#' z = abs(rnorm(10000, 10, 1))
+#' z <- abs(rnorm(10000, 10, 1))
 #'
 #' # expected to be closer to 0.
 #' VCI(z, by = 1, zmax = 20)
@@ -711,6 +702,6 @@ entropy = function(z, by = 1, zmax = NULL)
 #' @export VCI
 VCI = function(z, zmax, by = 1)
 {
-  z = z[z < zmax]
+  z <- z[z < zmax]
   return(entropy(z, by, zmax))
 }
