@@ -1,8 +1,7 @@
 context("grid_density")
 
-file <- system.file("extdata", "Megaplot.laz", package="lidR")
-ctg  <- catalog(file)
-las  <- readLAS(file)
+ctg  <- megaplot_ctg
+las  <- megaplot
 
 opt_chunk_buffer(ctg)    <- 0
 opt_chunk_size(ctg)      <- 160
@@ -17,9 +16,10 @@ test_that("grid_density returns the same both with LAScatalog and LAS", {
 
 
 test_that("grid_density returns pulse density", {
-  las <- laspulse(las)
+  las <- retrieve_pulses(las)
   d1 <- grid_density(las)
 
   expect_is(d1, "RasterBrick")
   expect_equal(names(d1), c("point_density", "pulse_density"))
 })
+
