@@ -1,7 +1,7 @@
 context("grid_terrain")
 rgdal::set_thin_PROJ6_warnings(TRUE)
 
-las <- lidR:::dummy_las(5000)
+las <- lidR:::generate_las(5000)
 projection(las) <- sp::CRS("+init=epsg:4326")
 las@data[, Z := round(Z + 0.1*X + 0.1*Y + sin(0.01*X) - sin(0.1*Y) + sin(0.003*X*Y),3)]
 
@@ -51,6 +51,8 @@ test_that("grid_terrain works with delaunay", {
 
 test_that("grid_terrain works with kriging", {
 
+  skip_if_not_installed("gstat")
+
   dtm <- grid_terrain(las, 1, kriging(k = 10L))
 
   expect_true(is(dtm, "RasterLayer"))
@@ -87,7 +89,7 @@ test_that("grid_terrain option keep_lowest works", {
   expect_true(!anyNA(z))
 })
 
-las2 <- lasclipCircle(las, 50, 50, 40)
+las2 <- clip_circle(las, 50, 50, 40)
 
 test_that("grid_terrain returns a circular dtm ", {
 
@@ -99,19 +101,18 @@ test_that("grid_terrain returns a circular dtm ", {
   expect_equal(names(dtm), "Z")
 
   error <- suppressWarnings(abs(dtm - tdtm))
-  expect_equal(mean(error[], na.rm = TRUE), 0.0655, tolerance = 0.0005)
+  expect_equal(mean(error[], na.rm = TRUE), 0.07, tolerance = 0.0005)
 
   z <- raster::extract(dtm, las2@data[, .(X,Y)])
   expect_true(!anyNA(z))
 })
 
-file <- system.file("extdata", "Topography.laz", package = "lidR")
-ctg  <- catalog(file)
-las  <- readLAS(file)
+ctg  <- topography_ctg
+las  <- topography
 
-opt_chunk_size(ctg)      <- 180
+opt_chunk_size(ctg)      <- 300
 opt_chunk_buffer(ctg)    <- 30
-opt_chunk_alignment(ctg) <- c(332400, 5238400)
+opt_chunk_alignment(ctg) <- c(50, 200)
 opt_progress(ctg)        <- FALSE
 
 test_that("grid_terrain returns the same both with LAScatalog and LAS", {
@@ -125,9 +126,8 @@ test_that("grid_terrain returns the same both with LAScatalog and LAS", {
   cdtm2 <- raster::crop(dtm2, bbox)
 
   error <- abs(cdtm1 - cdtm2)
-  error <- error[error > 0.01]
 
-  expect_equal(mean(error), 0.0195, tolerance = 0.001)
+  expect_equal(mean(error[]), 0, tolerance = 0.00001)
 
   z <- raster::extract(dtm2, las@data[, .(X,Y)])
   expect_true(!anyNA(z))
@@ -157,7 +157,5 @@ test_that("grid_terrain fails in some specific case", {
 
   las@data$Classification <- NULL
   expect_error(grid_terrain(las, 1, tin()), "LAS object does not contain 'Classification' attribute")
-
-
 })
 
